@@ -612,6 +612,10 @@ def march_conan_manip(conanobj):
         march_id = str(conanobj.options.march_id)
         conanobj.march_from_cpuid = False
 
+        if march_id == "x86-64-v3":
+            march_id = get_base_march_ids()[0]
+            conanobj.output.info(f"x86-64-v3 microarchitecture ID is translated to {march_id}")
+
         conanobj.march_data = get_all_data_from_marchid(
                                         march_id,
                                         str(conanobj.settings.os),
@@ -732,6 +736,9 @@ class KnuthConanFile(ConanFile):
         if self.settings.compiler == "Visual Studio":
             raise ConanInvalidConfiguration(f"MSVC is not supported.")
 
+        if self.settings.os == "Linux" and self.settings.compiler == "gcc" and self.settings.compiler.libcxx == "libstdc++":
+            raise ConanInvalidConfiguration("We just support GCC C++11ABI.\n**** Please run `conan profile update settings.compiler.libcxx=libstdc++11 default`")
+
         if self.settings.arch == "x86_64":
             if self.options.get_safe("march_id") is None:
                 raise ConanInvalidConfiguration("The recipe does not implement the march_id option.")
@@ -960,7 +967,7 @@ class KnuthConanFile(ConanFile):
             cmake.definitions["CONAN_CXX_FLAGS"] = cmake.definitions.get("CONAN_CXX_FLAGS", "") + " /DBOOST_CONFIG_SUPPRESS_OUTDATED_MESSAGE"
 
         if self.options.get_safe("march_id") is not None:
-            cmake.definitions["KTH_MARCH_ID"] = self.options.march_id
+            cmake.definitions["MARCH_ID"] = self.options.march_id
 
         cmake.definitions["KTH_PROJECT_VERSION"] = self.version
 
